@@ -3,11 +3,21 @@
 
 #include <sys/types.h>
 
+#ifndef CRLF
+#define CR '\r'
+#define LF '\n'
+#define CRLF "\r\n"
+#endif
+#define AT '@'
+#define NUL '\0'
+
 #define BUFSIZE 4096
 #define CLIENT_IN 0
 #define CLIENT_OUT 1
 extern int SERVER_FD;
 
+struct str;
+
 typedef int bool;
 #define true ((bool)(0==0))
 #define false ((bool)0)
@@ -23,6 +33,10 @@ extern const char filter_connfail_suffix[];
 extern void filter_init(int argc, char** argv);
 extern void filter_deinit(void);
 
+/* Functions from base64.c */
+extern int base64decode(const char* data, unsigned long size, struct str* dest);
+extern int base64encode(const char* data, unsigned long size, struct str* dest);
+
 /* Functions from ucspi-proxy.c */
 extern void usage(const char*);
 extern int opt_verbose;
